pype32.baseclasses.DataTypeBaseClass

Package pype32 :: Module baseclasses :: Class DataTypeBaseClass |
[hide private]
[frames] | no frames]

# Class DataTypeBaseClass

source code

    object --+
             |
            DataTypeBaseClass

Known Subclasses:
  - datatypes.BYTE
  - , datatypes.DWORD
  - , datatypes.QWORD
  - , datatypes.WORD

Instance Methods | [hide private]
__add__(self, other) | source code
__and__(self, other) | source code
__div__(self, other) | source code
__eq__(self, other) | source code
__ge__(self, other) | source code
__gt__(self, other) | source code
__init__(self, value=0, endianness=`'``<``'`, signed=False, shouldPack=True) x.__init__(...) initializes x; see help(type(x)) for signature | source code
__le__(self, other) | source code
__lshift__(self, other) | source code
__lt__(self, other) | source code
__mul__(self, other) | source code
__ne__(self, other) | source code
__or__(self, other) | source code
__rshift__(self, other) | source code
__sub__(self, other) | source code
__xor__(self, other) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, value=0, endianness=`'``<``'`, signed=False, shouldPack=True) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Parameters: `value` (int) - The value used to build the BYTE object. `endianness` (str) - (Optional) Indicates the endianness of the BYTE object. The `<` indicates little-endian while `>` indicates big-endian. `signed` (bool) - (Optional) If set to `True` the BYTE object will be packed as signed. If set to `False` it will be packed as unsigned. `shouldPack` (bool) - (Optional) If set to c{True}, the object will be packed. If set to `False`, the object won't be packed. Overrides: object.__init__